From kaneshige.kenji@soft.fujitsu.com Thu Apr  7 22:52:21 2005
Date: Fri, 08 Apr 2005 14:53:31 +0900
From: Kenji Kaneshige <kaneshige.kenji@soft.fujitsu.com>
To: Andrew Morton <akpm@osdl.org>, Greg KH <greg@kroah.com>,
        Linux Kernel Mailing List <linux-kernel@vger.kernel.org>
Subject: PCI: 'is_enabled' flag should be set/cleared when the device is actually enabled/disabled
Content-Length: 1392
Lines: 48


I think 'is_enabled' flag in pci_dev structure should be set/cleared
when the device actually enabled/disabled. Especially about
pci_enable_device(), it can be failed. By this change, we will also
get the possibility of refering 'is_enabled' flag from the functions
called through pci_enable_device()/pci_disable_device().

Signed-off-by: Kenji Kaneshige <kaneshige.kenji@jp.fujitsu.com>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>


--- gregkh-2.6.orig/drivers/pci/pci.c	2005-04-12 22:36:19.000000000 -0700
+++ gregkh-2.6/drivers/pci/pci.c	2005-04-12 22:38:27.000000000 -0700
@@ -398,10 +398,10 @@
 {
 	int err;
 
-	dev->is_enabled = 1;
 	if ((err = pci_enable_device_bars(dev, (1 << PCI_NUM_RESOURCES) - 1)))
 		return err;
 	pci_fixup_device(pci_fixup_enable, dev);
+	dev->is_enabled = 1;
 	return 0;
 }
 
@@ -427,16 +427,15 @@
 {
 	u16 pci_command;
 	
-	dev->is_enabled = 0;
-	dev->is_busmaster = 0;
-
 	pci_read_config_word(dev, PCI_COMMAND, &pci_command);
 	if (pci_command & PCI_COMMAND_MASTER) {
 		pci_command &= ~PCI_COMMAND_MASTER;
 		pci_write_config_word(dev, PCI_COMMAND, pci_command);
 	}
+	dev->is_busmaster = 0;
 
 	pcibios_disable_device(dev);
+	dev->is_enabled = 0;
 }
 
 /**
